==> tmw-0.0.17.tar.gz: tmw-0.0.17/src/gui/minimap.h <==
/*
 *  The Mana World
 *  Copyright 2004-2005 The Mana World Development Team
 *
 *  This file is part of The Mana World.
 *
 *  The Mana World is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  The Mana World is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with The Mana World; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: minimap.h,v 1.8 2005/09/28 22:19:06 bertram25 Exp $
 */

#ifndef _TMW_MINIMAP_H
#define _TMW_MINIMAP_H 

#include "window.h"

class Map;
class Image;

/**
 * Minimap dialog.
 *
 * \ingroup Interface
 */
class Minimap : public Window
{
    public:
        /**
         * Constructor.
         */
        Minimap();

        /**
         * Destructor.
         */
        ~Minimap();

        /**
         * Sets the map that should be displayed.
         */
        void setMap(Map *map);

        /**
         * Draws the minimap.
         */
        void draw(gcn::Graphics *graphics);

    private:
        Image *mMapImage;
};

extern Minimap *minimap;

#endif

==> tmw-0.0.19.tar.gz: tmw-0.0.19/src/gui/minimap.h <==
/*
 *  The Mana World
 *  Copyright 2004-2005 The Mana World Development Team
 *
 *  This file is part of The Mana World.
 *
 *  The Mana World is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  any later version.
 *
 *  The Mana World is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with The Mana World; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *  $Id: minimap.h 2184 2006-02-23 16:02:00Z der_doener $
 */

#ifndef _TMW_MINIMAP_H
#define _TMW_MINIMAP_H 

#include "window.h"

class Image;

/**
 * Minimap dialog.
 *
 * \ingroup Interface
 */
class Minimap : public Window
{
    public:
        /**
         * Constructor.
         */
        Minimap();

        /**
         * Destructor.
         */
        ~Minimap();

        /**
         * Sets the map image that should be displayed.
         */
        void setMapImage(Image *img);

        /**
         * Draws the minimap.
         */
        void draw(gcn::Graphics *graphics);

    private:
        Image *mMapImage;
};

extern Minimap *minimap;

#endif
